package org.acme.mqtt;

import io.quarkus.test.junit.QuarkusIntegrationTest;

@QuarkusIntegrationTest
public class PriceResourceIT extends PriceResourceTest {
}
